==> flutter_slider-0.0.1.tar.gz: lib/src/intro_page_item.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_slider/src/page_transformer.dart';

class SlideItem {
  SlideItem({
    this.title,
    this.category,
    this.imageUrl,
  });

  final String title;
  final String category;
  final String imageUrl;
}
class SlidePageItem extends StatelessWidget {
  SlidePageItem({
    @required this.item,
    @required this.pageVisibility,
    this.handleOnTap,
  });

  final SlideItem item;
  final PageVisibility pageVisibility;
  final Function handleOnTap;

  Widget _applyTextEffects({
    @required double translationFactor,
    @required Widget child,
  }) {
    final double xTranslation = pageVisibility.pagePosition * translationFactor;

    return new Opacity(
      opacity: pageVisibility.visibleFraction,
      child: new Transform(
        alignment: FractionalOffset.topLeft,
        transform: new Matrix4.translationValues(
          xTranslation,
          0.0,
          0.0,
        ),
        child: child,
      ),
    );
  }

  _buildTextContainer(BuildContext context) {
    final TextTheme textTheme = Theme.of(context).textTheme;
    final categoryText = _applyTextEffects(
      translationFactor: 300.0,
      child: new Text(
        item.category,
        style: textTheme.caption.copyWith(
          color: Colors.white70,
          fontWeight: FontWeight.bold,
          letterSpacing: 2.0,
          fontSize: 14.0,
        ),
        textAlign: TextAlign.center,
      ),
    );

    final titleText = _applyTextEffects(
      translationFactor: 200.0,
      child: new Padding(
        padding: const EdgeInsets.only(top: 16.0),
        child: new Text(
          item.title,
          style: textTheme.title
              .copyWith(color: Colors.white, fontWeight: FontWeight.bold),
          textAlign: TextAlign.center,
        ),
      ),
    );

    return new Positioned(
      bottom: 56.0,
      left: 32.0,
      right: 32.0,
      child: new Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          categoryText,
          titleText,
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    final image = new Image.asset(
      item.imageUrl,
      fit: BoxFit.cover,
      alignment: new FractionalOffset(
        0.5 + (pageVisibility.pagePosition / 3),
        0.5,
      ),
    );

    final imageOverlayGradient = new DecoratedBox(
      decoration: new BoxDecoration(
        gradient: new LinearGradient(
          begin: FractionalOffset.bottomCenter,
          end: FractionalOffset.topCenter,
          colors: [
            const Color(0xFF000000),
            const Color(0x00000000),
          ],
        ),
      ),
    );

    return new Padding(
      padding: const EdgeInsets.symmetric(
        vertical: 16.0,
        horizontal: 8.0,
      ),
      child: new GestureDetector(
        onTap: handleOnTap,
        child:
          new Material(
            elevation: 4.0,
            borderRadius: new BorderRadius.circular(8.0),
            child: new Stack(
              fit: StackFit.expand,
              children: [
                image,
                imageOverlayGradient,
                _buildTextContainer(context),
              ],
            ),
          ),
      ),
    );
  }
}

==> flutter_slider-0.0.2.tar.gz: lib/src/intro_page_item.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_slider/src/page_transformer.dart';

class SlideItem {
  SlideItem({
    this.title,
    this.category,
    this.imageUrl,
    this.id,
  });

  final String title;
  final String category;
  final String imageUrl;
  final Object id;
}
class SlidePageItem extends StatelessWidget {
  SlidePageItem({
    @required this.item,
    @required this.pageVisibility,
    @required this.handleOnTap,
  });

  final SlideItem item;
  final PageVisibility pageVisibility;
  final Function handleOnTap;

  Widget _applyTextEffects({
    @required double translationFactor,
    @required Widget child,
  }) {
    final double xTranslation = pageVisibility.pagePosition * translationFactor;

    return new Opacity(
      opacity: pageVisibility.visibleFraction,
      child: new Transform(
        alignment: FractionalOffset.topLeft,
        transform: new Matrix4.translationValues(
          xTranslation,
          0.0,
          0.0,
        ),
        child: child,
      ),
    );
  }

  _buildTextContainer(BuildContext context) {
    final TextTheme textTheme = Theme.of(context).textTheme;
    final categoryText = _applyTextEffects(
      translationFactor: 300.0,
      child: new Text(
        item.category,
        style: textTheme.caption.copyWith(
          color: Colors.white70,
          fontWeight: FontWeight.bold,
          letterSpacing: 2.0,
          fontSize: 14.0,
        ),
        textAlign: TextAlign.center,
      ),
    );

    final titleText = _applyTextEffects(
      translationFactor: 200.0,
      child: new Padding(
        padding: const EdgeInsets.only(top: 16.0),
        child: new Text(
          item.title,
          style: textTheme.title
              .copyWith(color: Colors.white, fontWeight: FontWeight.bold),
          textAlign: TextAlign.center,
        ),
      ),
    );

    return new Positioned(
      bottom: 56.0,
      left: 32.0,
      right: 32.0,
      child: new Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          categoryText,
          titleText,
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    final image = new Image.asset(
      item.imageUrl,
      fit: BoxFit.cover,
      alignment: new FractionalOffset(
        0.5 + (pageVisibility.pagePosition / 3),
        0.5,
      ),
    );

    final imageOverlayGradient = new DecoratedBox(
      decoration: new BoxDecoration(
        gradient: new LinearGradient(
          begin: FractionalOffset.bottomCenter,
          end: FractionalOffset.topCenter,
          colors: [
            const Color(0xFF000000),
            const Color(0x00000000),
          ],
        ),
      ),
    );

    return new Padding(
      padding: const EdgeInsets.symmetric(
        vertical: 16.0,
        horizontal: 8.0,
      ),
      child:
        new GestureDetector(
          onTap: handleOnTap,
          child: new Material(
            elevation: 4.0,
            borderRadius: new BorderRadius.circular(8.0),
            child: new Stack(
              fit: StackFit.expand,
              children: [
                image,
                imageOverlayGradient,
                _buildTextContainer(context),
              ],
            ),
          ),
        )
    );
  }
}
